@@ -252,6 +252,7 @@ export default class CellUtilities {
    * @param notebook The notebook to select the cell from
    * @param index The index of the cell to inject the code into
    * @param code A string containing the code to inject into the CodeCell.
+   * @param checkCodeCell To check if the cell is a CodeCellModel
    * @throws An error message if there are issues with injecting code at a particular cell
    * @returns void
    */
@@ -259,6 +260,7 @@ export default class CellUtilities {
     notebook: Notebook,
     index: number,
     code: string,
+    checkCodeCell: boolean = false
   ): void {
     if (notebook === null) {
       throw new Error('Notebook was null or undefined.');
@@ -267,11 +269,11 @@ export default class CellUtilities {
       throw new Error('Cell index out of range.');
     }
     const cell: ICellModel = notebook.model.cells.get(index);
-    if (isCodeCellModel(cell)) {
-      cell.value.text = code;
-      return;
+    if (checkCodeCell && ! isCodeCellModel(cell)) {
+      throw new Error('Cell is not a code cell.');
     }
-    throw new Error('Cell is not a code cell.');
+    cell.value.text = code;
+    return;
   }
 
   /**
@@ -413,16 +415,13 @@ export default class CellUtilities {
       throw new Error('Cell index out of range.');
     }
     const cell: ICellModel = notebook.model.cells.get(index);
-    if (isCodeCellModel(cell)) {
-      if(cell.value.text) {
-        if(cell.value.text.trim().length === 0) {
-          return true;
-        }
-        return false;
+    if(cell.value.text) {
+      if(cell.value.text.trim().length === 0) {
+        return true;
       }
-      return true;
+      return false;
     }
-    throw new Error('Cell is not a code cell.');
+    return true;
   }
 
   public static isTextInCell(
@@ -437,15 +436,12 @@ export default class CellUtilities {
       throw new Error('Cell index out of range.');
     }
     const cell: ICellModel = notebook.model.cells.get(index);
-    if (isCodeCellModel(cell)) {
-      if(cell.value.text) {
-        let ind = cell.value.text.search(regex);
-        if(ind >= 0) {
-          return true;
-        }
+    if(cell.value.text) {
+      let ind = cell.value.text.search(regex);
+      if(ind >= 0) {
+        return true;
       }
-      return false;
     }
-    throw new Error('Cell is not a code cell.');
+    return false;
   }
 }
