@@ -69,9 +69,10 @@ export default class NotebookUtilities {
   private static buildDialogBody(msg: string[]): ReactElement {
     return (
       <div className="dialog-body">
-        {msg.map((s: string, i: number) => {
+        {msg.map((str: string, i: number) => {
           return (
             <React.Fragment key={`msg-${i}`}>
+              <p>{str}</p>
             </React.Fragment>
           );
         })}
