@@ -4,12 +4,10 @@ import { Token } from '@lumino/coreutils';
 const id = 'transformer-extension:ITransformerStates';
 const ITransformerStates = new Token<ITransformerStates>(id);
 export interface ITransformerStates {
-    isPreprocessorTagged?: boolean;
-    isPostprocessorTagged?: boolean;
+    isPredictTagged?: boolean;
     isRequirementsTagged?: boolean;
     isCVATInfoTagged?: boolean;
-    isCVATPreprocessorTagged?: boolean;
-    isCVATPostprocessorTagged?: boolean;
+    isCVATInvokeTagged?: boolean;
 }
 
 let transformerStatesList: {
@@ -21,12 +19,10 @@ let transformerStatesList: {
 const assertTransformerStates = (notebookPanelId: string) => {
     if(! transformerStatesList[notebookPanelId]) {
         let transformerStates: ITransformerStates = {
-            isPreprocessorTagged: false,
-            isPostprocessorTagged: false,
+            isPredictTagged: false,
             isRequirementsTagged: false,
             isCVATInfoTagged: false,
-            isCVATPreprocessorTagged: false,
-            isCVATPostprocessorTagged: false
+            isCVATInvokeTagged: false
         }
         let stateChangeListeners: ((trigger: string, newStates: ITransformerStates) => void)[] = [];
         transformerStatesList[notebookPanelId] = {
