@@ -87,15 +87,18 @@ export const RESERVED_CELL_NAMES_CHIP_COLOR = CELL_TYPES
         return obj;
     } ,{});
 
-const PREDICT_DEF_REGEX = /\s*def\s+predict\s*\((\s*\w+\s*(:\s*\w+\s*)?(=[\w\W]+)?,?){0,2}\)\s*(->\s*\S+\s*)?:\s*/i
+const PREDICT_DEF_REGEX = /\s*def\s+predict\s*\((\s*[\., \w]+\s*(:\s*[\., \s, \w]+\s*)?(=[\w\W]+)?,?){0,3}\)\s*(->\s*\S+\s*)?:\s*/i
 const PREDICT_DEFAULT_CODE_SNIPPET = `from typing import Dict
-from flask import redirect
-def predict(input: Dict, model_predict_url: str) -> Dict:
-    return redirect(model_predict_url)`
+import flask
+from prometheus_client import Counter, Gauge, Summary, Histogram
+def predict(request: flask.Request, model_predict_url: str, predict_metric_type: Counter or Gauge or Summary or Histogram = None) -> Dict:
+    # Notice: once you reconstruct the predict_metric_type object, return it as the second return value.
+    return flask.redirect(model_predict_url)`
 
-const CVAT_INFO_DEF_REGEX = /\s*def\s+cvat_info\s*\((\s*\w+\s*(:\s*\w+\s*)?(=[\w\W]+)?,?){0,1}\)\s*(->\s*\S+\s*)?:\s*/i
+const CVAT_INFO_DEF_REGEX = /\s*def\s+cvat_info\s*\((\s*[\., \w]+\s*(:\s*[\., \s, \w]+\s*)?(=[\w\W]+)?,?){0,1}\)\s*(->\s*\S+\s*)?:\s*/i
 const CVAT_INFO_DEFAULT_CODE_SNIPPET = `from typing import Dict
-def cvat_info(inputs: Dict = None) -> Dict:
+import flask
+def cvat_info(request: flask.Request) -> Dict:
     return {
         "framework": "",
         "spec": None,
@@ -103,10 +106,12 @@ def cvat_info(inputs: Dict = None) -> Dict:
         "description": ""
     }`
 
-const CVAT_INVOKE_DEF_REGEX = /\s*def\s+cvat_invoke\s*\((\s*\w+\s*(:\s*\w+\s*)?(=[\w\W]+)?,?){0,2}\)\s*(->\s*\S+\s*)?:\s*/i
+const CVAT_INVOKE_DEF_REGEX = /\s*def\s+cvat_invoke\s*\((\s*[\., \w]+\s*(:\s*[\., \s, \w]+\s*)?(=[\w\W]+)?,?){0,3}\)\s*(->\s*\S+\s*)?:\s*/i
 const CVAT_INVOKE_DEFAULT_CODE_SNIPPET = `from typing import Dict
-from flask import redirect
-def cvat_invoke(input: Dict, model_predict_url: str) -> Dict:
+import flask
+from prometheus_client import Counter, Gauge, Summary, Histogram
+def cvat_invoke(request: flask.Request, model_predict_url: str, cvat_invoke_metric_type: Counter or Gauge or Summary or Histogram = None) -> Dict:
+    # Notice: once you reconstruct the predict_metric_type object, return it as the second return value.
     return []`
 
 const enum CellCodeErrors {
