@@ -197,10 +197,8 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
         } catch (error) {
             globalUnhandledRejection({ reason: error });
             this.renderDialog({
-                title: 'Error',
-                content: error
+                visible: false
             });
-            throw error;
         }
         this.setState({ dialogConfirmClickHandler: this.onDialogConfirmClick });
     };
@@ -251,10 +249,8 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
         } catch (error) {
             globalUnhandledRejection({ reason: error });
             this.renderDialog({
-                title: 'Error',
-                content: error
+                visible: false
             });
-            throw error;
         }
     };
 
@@ -279,7 +275,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
 
                         <div className='transformer-component' >
                             <Typography variant="body1" gutterBottom style={{ color: theme.transformer.headers.main }}>
-                                Transformer is the extension for model inference, it injects pre and post processors defined in <strong style={{ fontWeight: '600' }}>transformer.ipynb</strong> notebook.
+                                Transformer is the extension for model inference, it helps you customizing the proxy API handlers by defining the corresponding functions on <strong style={{ fontWeight: '600' }}>transformer.ipynb</strong> notebook.
                             </Typography>
                         </div>
 
@@ -379,7 +375,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
                             </Typography>
                             <Collapse in={this.state.showApplyTransformerDescription} timeout="auto" unmountOnExit>
                                 <Typography variant="body1" gutterBottom style={{ color: theme.transformer.headers.main }}>
-                                    Convert <strong style={{ fontWeight: '600' }}>transformer.ipynb</strong> to runnable python code and apply the pre and post processors for model inference.
+                                    Convert <strong style={{ fontWeight: '600' }}>transformer.ipynb</strong> to runnable handlers and apply them on proxy.
                                 </Typography>
                             </Collapse>
                             <div className="input-container add-button">
@@ -409,7 +405,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
                                 <Typography variant="body1" gutterBottom style={{ color: theme.transformer.headers.main }}>
                                     <strong style={{ fontWeight: '600' }}>Reset {this.state.transformerNotebookPath? this.state.transformerNotebookPath: 'transformer.ipynb'}</strong>
                                     <br />
-                                    This action also reset the pre and post processors for model inference.
+                                    This action also reset the API handlers on proxy.
                                 </Typography>
                             </Collapse>
                             <div className="input-container add-button">
